//**************************************************************************//
//**                                                                      **//
//**                            MF6502                                    **//
//**                                                                      **//
//**   Copyright (C) Dott. Cosimo De Michele 1998                         **//
//**         You are not allowed to distribuite this software             **//
//**         commercially. Please, notify me, if you make any             **//
//**         changes to this file.                                        **//
//**                                                                      **//
//**   This unit is a wrapper around the portable 6502 emulator           **//
//**   "M6502" of Marat Fayzullin.                                        **//
//**   This file contains implementation for 6502 CPU. Don't              **//
//**   forget to provide Rd6502(), Wr6502(), Loop6502(), and              **//
//**   possibly Op6502() functions to accomodate the emulated             **//
//**   machine's architecture.                                            **//
//**                                                                      **//
//**   Copyright (C) Marat Fayzullin 1996                                 **//
//**                 Alex Krasivsky  1996                                 **//
//**                                                                      **//
//**************************************************************************//

unit MF6502;

interface

const
  INT_NONE: byte = 0;            //* No interrupt required      */
  INT_IRQ : byte = 1;            //* Standard IRQ interrupt     */
  INT_NMI : byte = 2;            //* Non-maskable interrupt     */
  INT_QUIT: byte = 3;            //* Exit the emulation         */

type
  PairByte = record
    h,l: byte;
  end;

  Pair = record
   case integer of
     0: (B: PairByte);
     1: (W: word );
  end;

  M6502 = record
    A,P,X,Y,S: byte;
    PC: Pair;
    IPeriod,ICount: integer;
    IRequest: byte;
    AfterCLI: byte;
    IBackup: integer;
    //void *User;
    TrapBadOps: byte;
    Trap: word;
    Trace: byte;
  end;

  procedure Wr6502(Addr: word; Value: byte ); register;
  function  Rd6502(Addr: word): byte; register;
  function  Op6502(Addr: word ): byte; register ;
  function  Loop6502(var R: M6502): byte; register;
  {$L M6502.OBJ}
  function  Exec6502(var R : M6502) : word; register; external;
  procedure Int6502(var R: M6502; Tp: byte); register; external;
  function  Run6502(var R: M6502): word; register; external;
  procedure Reset6502(var R: M6502); register; external;

implementation

uses MainForm;

procedure Wr6502(Addr: word; value: byte );
begin
  frmMain.MemoryWrite(Addr,value);
end;

function Rd6502(Addr: word): byte;
begin
  Result:=frmMain.MemoryReadByte(Addr);
end;

function Op6502(Addr: word ): byte;
begin
  Result:=frmMain.MemoryReadOpCode(Addr);
end;

function Loop6502(var R: M6502): byte;
begin
  Result:= frmMain.cpuLoop;
end;

end.
